Struct google_cloudbilling1::api::ListBillingAccountsResponse[][src]

pub struct ListBillingAccountsResponse {
    pub billing_accounts: Option<Vec<BillingAccount>>,
    pub next_page_token: Option<String>,
}

Response message for ListBillingAccounts.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

billing_accounts: Option<Vec<BillingAccount>>

A list of billing accounts.

next_page_token: Option<String>

A token to retrieve the next page of results. To retrieve the next page, call ListBillingAccounts again with the page_token field set to this value. This field is empty if there are no more results to retrieve.