pub struct ListProjectBillingInfoResponse {
pub next_page_token: Option<String>,
pub project_billing_info: Option<Vec<ProjectBillingInfo>>,
}Expand description
Request message for ListProjectBillingInfoResponse.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- projects list billing accounts (response)
Fields
next_page_token: Option<String>A token to retrieve the next page of results. To retrieve the next page, call ListProjectBillingInfo again with the page_token field set to this value. This field is empty if there are no more results to retrieve.
project_billing_info: Option<Vec<ProjectBillingInfo>>A list of ProjectBillingInfo resources representing the projects associated with the billing account.