Struct google_cloudbilling1::api::PricingInfo [−][src]
Represents the pricing information for a SKU at a single point of time.
This type is not used in any activity, and only used as part of another schema.
Fields
aggregation_info: Option<AggregationInfo>Aggregation Info. This can be left unspecified if the pricing expression doesn’t require aggregation.
currency_conversion_rate: Option<f64>Conversion rate used for currency conversion, from USD to the currency specified in the request. This includes any surcharge collected for billing in non USD currency. If a currency is not specified in the request this defaults to 1.0. Example: USD * currency_conversion_rate = JPY
effective_time: Option<String>The timestamp from which this pricing was effective within the requested time range. This is guaranteed to be greater than or equal to the start_time field in the request and less than the end_time field in the request. If a time range was not specified in the request this field will be equivalent to a time within the last 12 hours, indicating the latest pricing info.
pricing_expression: Option<PricingExpression>Expresses the pricing formula. See PricingExpression for an example.
summary: Option<String>An optional human readable summary of the pricing information, has a maximum length of 256 characters.